@@ -427,52 +427,3 @@ footers_replace_all_text <- function( x, old_value, new_value, only_at_cursor =
   x
 }
 
-#' @export
-#' @title Remove unused media from a document
-#' @description The function will scan the media
-#' directory and delete images that are not used
-#' anymore. This function is to be used when images
-#' have been replaced many times.
-#' @param x `rdocx` or `rpptx` object
-#' @keywords internal
-sanitize_images <- function(x){
-
-  rel_files <- list.files(x$package_dir, pattern = "\\.xml.rels$", recursive = TRUE, full.names = TRUE)
-
-  image_files <- lapply(rel_files,
-                        function(x){
-                          zz <- read_xml(x)
-                          rels <- xml_children(zz)
-                          rels <- rels[xml_attr(rels, "Type") %in% "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image"]
-                          xml_attr(rels, "Target")
-                        })
-  image_files <- unique(unlist(image_files))
-
-  if(inherits(x, "rdocx")){
-    base_doc <- file.path(x$package_dir, "word")
-    existing_img <- list.files(
-      file.path(base_doc, "media"),
-      pattern = "\\.(png|jpg|jpeg|eps|emf)$",
-      ignore.case = TRUE,
-      recursive = TRUE, full.names = TRUE)
-    existing_img <- gsub(paste0(base_doc, "/"), "", existing_img, fixed = TRUE)
-    unlink(file.path(base_doc,
-                     setdiff(image_files, existing_img)
-                     ), force = TRUE)
-  } else if(inherits(x, "rpptx")){
-    base_doc <- file.path(x$package_dir, "ppt")
-    existing_img <- list.files(
-      file.path(base_doc, "media"),
-      pattern = "\\.(png|jpg|jpeg|eps|emf)$",
-      ignore.case = TRUE,
-      recursive = TRUE, full.names = TRUE)
-    existing_img <- gsub(paste0(base_doc, "/"), "",
-                         existing_img, fixed = TRUE)
-    unlink(file.path(base_doc, setdiff(image_files, existing_img)), force = TRUE)
-  }
-  x
-}
-
-
-
-
