@@ -121,8 +121,7 @@ on_slide <- function(x, index) {
 #' @description Remove a slide from a pptx presentation.
 #' @param x an rpptx object
 #' @param index slide index, default to current slide position.
-#' @param rm_images if TRUE (defaults to FALSE), images presented in
-#' the slide to remove are also removed from the file.
+#' @param rm_images unused anymore.
 #' @note cursor is set on the last slide.
 #' @examples
 #' my_pres <- read_pptx()
@@ -146,13 +145,6 @@ remove_slide <- function(x, index = NULL, rm_images = FALSE) {
   filename <- basename(x$presentation$slide_data()$target[index])
   location <- which(x$slide$get_metadata()$name %in% filename)
 
-  if (rm_images) {
-    media_files <- pptx_summary(x)$media_file
-    if (length(media_files)) {
-      unlink(file.path(x$package_dir, media_files), force = TRUE)
-    }
-  }
-
   del_file <- x$slide$remove_slide(location)
 
   # update presentation elements
